# 2022-03-25 - BAL Token Holder Factory

Deployment of `BALTokenHolderFactory` which deploys simple contracts which holds BAL tokens such that only addresses specified by Balancer governance may withdraw them.

## Useful Files

- [Ethereum mainnet addresses](./output/mainnet.json)
- [Goerli testnet addresses](./output/goerli.json)
- [Sepolia testnet addresses](./output/sepolia.json)
- [`BALTokenHolderFactory` artifact](./artifact/BALTokenHolderFactory.json)
